"Main interface for cloudsearch service Client"
from typing import Any, Dict, List
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_cloudsearch.client as client_scope
from mypy_boto3_cloudsearch.type_defs import (
    AnalysisSchemeTypeDef,
    BuildSuggestersResponseTypeDef,
    CreateDomainResponseTypeDef,
    DefineAnalysisSchemeResponseTypeDef,
    DefineExpressionResponseTypeDef,
    DefineIndexFieldResponseTypeDef,
    DefineSuggesterResponseTypeDef,
    DeleteAnalysisSchemeResponseTypeDef,
    DeleteDomainResponseTypeDef,
    DeleteExpressionResponseTypeDef,
    DeleteIndexFieldResponseTypeDef,
    DeleteSuggesterResponseTypeDef,
    DescribeAnalysisSchemesResponseTypeDef,
    DescribeAvailabilityOptionsResponseTypeDef,
    DescribeDomainEndpointOptionsResponseTypeDef,
    DescribeDomainsResponseTypeDef,
    DescribeExpressionsResponseTypeDef,
    DescribeIndexFieldsResponseTypeDef,
    DescribeScalingParametersResponseTypeDef,
    DescribeServiceAccessPoliciesResponseTypeDef,
    DescribeSuggestersResponseTypeDef,
    DomainEndpointOptionsTypeDef,
    ExpressionTypeDef,
    IndexDocumentsResponseTypeDef,
    IndexFieldTypeDef,
    ListDomainNamesResponseTypeDef,
    ScalingParametersTypeDef,
    SuggesterTypeDef,
    UpdateAvailabilityOptionsResponseTypeDef,
    UpdateDomainEndpointOptionsResponseTypeDef,
    UpdateScalingParametersResponseTypeDef,
    UpdateServiceAccessPoliciesResponseTypeDef,
)


__all__ = ("CloudSearchClient",)


class CloudSearchClient(BaseClient):
    """
    [CloudSearch.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client)
    """

    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def build_suggesters(self, DomainName: str) -> BuildSuggestersResponseTypeDef:
        """
        [Client.build_suggesters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.build_suggesters)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.can_paginate)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_domain(self, DomainName: str) -> CreateDomainResponseTypeDef:
        """
        [Client.create_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.create_domain)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def define_analysis_scheme(
        self, DomainName: str, AnalysisScheme: AnalysisSchemeTypeDef
    ) -> DefineAnalysisSchemeResponseTypeDef:
        """
        [Client.define_analysis_scheme documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.define_analysis_scheme)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def define_expression(
        self, DomainName: str, Expression: ExpressionTypeDef
    ) -> DefineExpressionResponseTypeDef:
        """
        [Client.define_expression documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.define_expression)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def define_index_field(
        self, DomainName: str, IndexField: IndexFieldTypeDef
    ) -> DefineIndexFieldResponseTypeDef:
        """
        [Client.define_index_field documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.define_index_field)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def define_suggester(
        self, DomainName: str, Suggester: SuggesterTypeDef
    ) -> DefineSuggesterResponseTypeDef:
        """
        [Client.define_suggester documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.define_suggester)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_analysis_scheme(
        self, DomainName: str, AnalysisSchemeName: str
    ) -> DeleteAnalysisSchemeResponseTypeDef:
        """
        [Client.delete_analysis_scheme documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.delete_analysis_scheme)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_domain(self, DomainName: str) -> DeleteDomainResponseTypeDef:
        """
        [Client.delete_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.delete_domain)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_expression(
        self, DomainName: str, ExpressionName: str
    ) -> DeleteExpressionResponseTypeDef:
        """
        [Client.delete_expression documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.delete_expression)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_index_field(
        self, DomainName: str, IndexFieldName: str
    ) -> DeleteIndexFieldResponseTypeDef:
        """
        [Client.delete_index_field documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.delete_index_field)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_suggester(
        self, DomainName: str, SuggesterName: str
    ) -> DeleteSuggesterResponseTypeDef:
        """
        [Client.delete_suggester documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.delete_suggester)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_analysis_schemes(
        self, DomainName: str, AnalysisSchemeNames: List[str] = None, Deployed: bool = None
    ) -> DescribeAnalysisSchemesResponseTypeDef:
        """
        [Client.describe_analysis_schemes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_analysis_schemes)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_availability_options(
        self, DomainName: str, Deployed: bool = None
    ) -> DescribeAvailabilityOptionsResponseTypeDef:
        """
        [Client.describe_availability_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_availability_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_domain_endpoint_options(
        self, DomainName: str, Deployed: bool = None
    ) -> DescribeDomainEndpointOptionsResponseTypeDef:
        """
        [Client.describe_domain_endpoint_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_domain_endpoint_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_domains(self, DomainNames: List[str] = None) -> DescribeDomainsResponseTypeDef:
        """
        [Client.describe_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_domains)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_expressions(
        self, DomainName: str, ExpressionNames: List[str] = None, Deployed: bool = None
    ) -> DescribeExpressionsResponseTypeDef:
        """
        [Client.describe_expressions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_expressions)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_index_fields(
        self, DomainName: str, FieldNames: List[str] = None, Deployed: bool = None
    ) -> DescribeIndexFieldsResponseTypeDef:
        """
        [Client.describe_index_fields documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_index_fields)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_scaling_parameters(
        self, DomainName: str
    ) -> DescribeScalingParametersResponseTypeDef:
        """
        [Client.describe_scaling_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_scaling_parameters)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_service_access_policies(
        self, DomainName: str, Deployed: bool = None
    ) -> DescribeServiceAccessPoliciesResponseTypeDef:
        """
        [Client.describe_service_access_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_service_access_policies)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_suggesters(
        self, DomainName: str, SuggesterNames: List[str] = None, Deployed: bool = None
    ) -> DescribeSuggestersResponseTypeDef:
        """
        [Client.describe_suggesters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.describe_suggesters)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.generate_presigned_url)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def index_documents(self, DomainName: str) -> IndexDocumentsResponseTypeDef:
        """
        [Client.index_documents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.index_documents)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
        """
        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.list_domain_names)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_availability_options(
        self, DomainName: str, MultiAZ: bool
    ) -> UpdateAvailabilityOptionsResponseTypeDef:
        """
        [Client.update_availability_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.update_availability_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_domain_endpoint_options(
        self, DomainName: str, DomainEndpointOptions: DomainEndpointOptionsTypeDef
    ) -> UpdateDomainEndpointOptionsResponseTypeDef:
        """
        [Client.update_domain_endpoint_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.update_domain_endpoint_options)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_scaling_parameters(
        self, DomainName: str, ScalingParameters: ScalingParametersTypeDef
    ) -> UpdateScalingParametersResponseTypeDef:
        """
        [Client.update_scaling_parameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.update_scaling_parameters)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_service_access_policies(
        self, DomainName: str, AccessPolicies: str
    ) -> UpdateServiceAccessPoliciesResponseTypeDef:
        """
        [Client.update_service_access_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.37/reference/services/cloudsearch.html#CloudSearch.Client.update_service_access_policies)
        """


class Exceptions:
    BaseException: Boto3ClientError
    ClientError: Boto3ClientError
    DisabledOperationException: Boto3ClientError
    InternalException: Boto3ClientError
    InvalidTypeException: Boto3ClientError
    LimitExceededException: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError
    ValidationException: Boto3ClientError
